import React from 'react';
import { useForm } from 'react-hook-form';

import { Page } from './Page';
import {
  FieldInput,
  FieldLabel,
  Fieldset,
  FieldContainer,
  FieldTextArea,
  FormButtonContainer,
  PrimaryButton,
  FieldError,
} from './Styles';

type FormData = {
  title: string;
  content: string;
};

export const AskPage = () => {
  const { register, errors } = useForm<FormData>({
    mode: 'onBlur',
  });
  return (
    <Page title="Ask a question">
      <form>
        <Fieldset>
          <FieldContainer>
            <FieldLabel htmlFor="title">Title</FieldLabel>
            <FieldInput
              {...register('title', {
                required: true,
                minLength: 10,
              })}
              id="title"
              name="title"
              type="text"
            />
            {errors.title && errors.title.type === 'required' && (
              <FieldError>You must enter the question title</FieldError>
            )}
            {errors.title && errors.title.type === 'minLength' && (
              <FieldError>The title must be at least 10 characters</FieldError>
            )}
          </FieldContainer>
          <FieldContainer>
            <FieldLabel htmlFor="content">Content</FieldLabel>
            <FieldTextArea
              {...register('content')}
              id="content"
              name="content"
            />
          </FieldContainer>
          <FormButtonContainer>
            <PrimaryButton type="submit">Submit Your Question</PrimaryButton>
          </FormButtonContainer>
        </Fieldset>
      </form>
    </Page>
  );
};

export default AskPage;
